@@ -169,7 +169,7 @@ from ae.i18n import get_f_string
 from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action   # type: ignore
 
 
-__version__ = '0.1.27'
+__version__ = '0.1.28'
 
 
 FLOW_PATH_ROOT_ID = 'ROOT'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
@@ -348,7 +348,7 @@ class LiszDataMixin(ABC):
                 if item_idx >= 0:                                   # found the blocking/duplicate item id
                     if 'node' not in node_to_add_to[item_idx]:
                         node_to_add_to[item_idx]['node'] = list()   # convert blocking item from leaf to node
-                    err_msg = get_f_string("(ignorable) ") + err_msg
+                    err_msg = ("(ignorable) " + err_msg) if self.debug_level else ""
                     sub_err = self.add_items(nid['node'], node_to_add_to=node_to_add_to[item_idx]['node'])
                     if sub_err:                                     # add (ignorable?) errors from sub-node adds
                         err_msg += "\n" + sub_err
@@ -614,25 +614,26 @@ class LiszDataMixin(ABC):
         """ generate shortened display text from the passed flow path.
 
         :param flow_path:       flow path list.
-        :param min_len:         minimum length of node ids (flow id keys).
+        :param min_len:         minimum length of node ids (flow id keys). Pass zero value for to not shorten ids.
         :param display_root:    pass True to return FLOW_PATH_ROOT_ID on empty/root path.
         :param separator:       path item separator (default=FLOW_PATH_TEXT_SEP).
         :return:                shortened display text string of the passed flow path (which can be converted back
                                 to a flow path list with the method :meth:`.flow_path_from_text`).
         """
         path_nid = None         # suppress Pycharm PyUnboundLocalVariable inspection warning
+        shortening = bool(min_len)
         shortened_ids = list()
         node = self.root_node
         for flow_id in flow_path:
             if flow_action(flow_id) != 'enter':
                 continue
-            id_len = min_len
             node_id = flow_key(flow_id)
             sub_id_len = len(node_id)
+            id_len = min_len if shortening else sub_id_len
             for nid in node:
                 if nid['id'] == node_id:
                     path_nid = nid
-                elif 'node' in nid:
+                elif shortening:
                     while nid['id'].startswith(node_id[:id_len]) and id_len < sub_id_len:
                         id_len += 1
 
